@@ -168,7 +168,7 @@ class BaseHandler(RequestHandler):
             self.set_header("Access-Control-Allow-Origin", "*")
         self.set_header("Request-Id", self.request.headers.get("Request-Id", ""))
         self.set_header("Plugin-Running-Time", self.request.headers.get("Plugin-Running-Time", ""))
-        self.set_header("Access-Control-Allow-Headers", "x-requested-with,Authorization,Can-read-cache")
+        self.set_header("Access-Control-Allow-Headers", "x-requested-with,Authorization,Can-read-cache,Content-Type")
         self.set_header("Access-Control-Allow-Methods", "POST,GET,PUT,DELETE,OPTIONS")
         self.set_header("Access-Control-Expose-Headers", "Access-Token")
         self.set_header("Access-Control-Allow-Credentials", "true")
