@@ -143,3 +143,12 @@ class StatusCode:
     # C04开头的状态码
 
     # C05开头的状态码
+
+    @staticmethod
+    def COMMON_CODE_MESSAGE(status_code, message):
+        """
+        用于自定义消息提示信息
+        :param message: 替换的消息内容
+        :return:
+        """
+        return status_code, "{}".format(message)
