@@ -39,7 +39,7 @@ define("eureka_instance_port", default=8901, type=int, help="eureka实例ip或
 define("rms_register_enable", default=False, type=bool, help="是否启动资源注册")
 define("rms_register_server", default="http://127.0.0.1:8918", type=str, help="启动资源注册")
 define("running_env", default="local", type=str, help="运行环境")
-define("db", default=None, type=SQLAlchemy, help="SqlAlchemy")
+define("db", default=SQLAlchemy(), type=SQLAlchemy, help="SqlAlchemy")
 # 日志初始化配置，配置文件中可修改设置
 options.logging = "DEBUG"
 options.log_rotate_mode = "time"
